@@ -26,6 +26,7 @@ from oslo_config import cfg
 from oslo_log import log as logging
 
 from barbican.cmd import pkcs11_kek_rewrap as pkcs11_rewrap
+from barbican.cmd import simple_crypto_kek_rewrap
 from barbican.common import config
 from barbican.model import clean
 from barbican.model.migration import commands
@@ -326,13 +327,16 @@ class HSMCommands(object):
         elif type(slotid) is not int:
             slotid = int(slotid)
         if hmacwrap is None:
-            hmacwrap = conf.p11_crypto_plugin.hmac_keywrap_mechanism
+            hmacwrap = conf.p11_crypto_plugin.hmac_mechanism
 
         self.pkcs11 = pkcs11.PKCS11(
-            library_path=libpath, login_passphrase=passphrase,
-            rw_session=True, slot_id=slotid,
-            encryption_mechanism='CKM_AES_CBC',
-            hmac_keywrap_mechanism=hmacwrap,
+            library_path=libpath,
+            login_passphrase=passphrase,
+            rw_session=conf.p11_crypto_plugin.rw_session,
+            slot_id=slotid,
+            encryption_mechanism=conf.p11_crypto_plugin.encryption_mechanism,
+            hmac_mechanism=hmacwrap,
+            key_wrap_mechanism=conf.p11_crypto_plugin.key_wrap_mechanism,
             token_serial_number=conf.p11_crypto_plugin.token_serial_number,
             token_labels=conf.p11_crypto_plugin.token_labels
         )
@@ -345,9 +349,26 @@ class HSMCommands(object):
             sys.exit(1)
 
 
+class SimpleCryptoCommands:
+    """Class for mananging SimpleCryptoPlugin backend"""
+
+    description = "Subcommands for managing SimpleCryptoPlugin backend"
+
+    rewrap_pkek_description = "Re-wrap project KEKs"
+
+    @args('--dry-run', action='store_true', dest='dryrun', default=False,
+          help="Displays changes that will be made (non-destructive)")
+    def rewrap_pkek(self, conf, dryrun=True):
+        rewrapper = simple_crypto_kek_rewrap.SimpleCryptoKEKRewrap(
+            simple_crypto_kek_rewrap.CONF
+        )
+        rewrapper.execute(dryrun)
+
+
 CATEGORIES = {
     'db': DbCommands,
     'hsm': HSMCommands,
+    'simple_crypto': SimpleCryptoCommands,
 }
 
 
