@@ -12,10 +12,12 @@
 # implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-from oslo_serialization import jsonutils
+
 import sys
 import time
 
+from oslo_serialization import jsonutils as json
+import testtools
 from testtools import testcase
 
 from barbican.tests import utils
@@ -184,6 +186,25 @@ class OrdersTestCase(base.TestCase):
             secret_ref, payload_content_type="text/plain")
         self.assertEqual(406, secret_resp.status_code)
 
+    @testcase.attr('positive')
+    def test_order_create_check_secret_payload_positive(self):
+        """Create order and check the secret payload.
+
+        Check the secret payload with correct payload_content_type.
+        """
+        test_model = order_models.OrderModel(**self.create_default_data)
+        resp, order_ref = self.behaviors.create_order(test_model)
+        self.assertEqual(202, resp.status_code)
+        order_resp = self.behaviors.get_order(order_ref)
+        self.assertEqual(200, order_resp.status_code)
+        # PENDING orders may take a moment to be processed by the workers
+        # when running tests with queue enabled
+        self.wait_for_order(order_resp, order_ref)
+        secret_ref = order_resp.model.secret_ref
+        secret_resp = self.secret_behaviors.get_secret(
+            secret_ref, payload_content_type="application/octet-stream")
+        self.assertEqual(200, secret_resp.status_code)
+
     @testcase.attr('positive')
     def test_order_and_secret_metadata_same(self):
         """Checks that metadata from secret GET and order GET are the same.
@@ -295,7 +316,7 @@ class OrdersTestCase(base.TestCase):
         resp, order_ref = self.behaviors.create_order(test_model)
 
         # Make sure we actually get a message back
-        error_msg = jsonutils.loads(resp.content).get('title')
+        error_msg = json.loads(resp.content).get('title')
 
         self.assertEqual(400, resp.status_code)
         self.assertIsNotNone(error_msg)
@@ -567,6 +588,8 @@ class OrdersTestCase(base.TestCase):
         self.assertRegex(order_resp.model.order_ref, regex)
 
     @testcase.attr('positive')
+    @testtools.skipIf(utils.is_vault_enabled() or utils.is_pkcs11_enabled(),
+                      "Vault does not support this operation")
     def test_encryption_using_generated_key(self):
         """Tests functionality of a generated asymmetric key pair."""
         test_model = order_models.OrderModel(**self.asymmetric_data)
